@@ -15,7 +15,7 @@ def make_menu_bar(main):
         (_('Add Bookmark'), main._add_bookmark),
         (_('Show Bookmarks'), main._list_bookmarks),
         (_('About'), main._show_about),
-	(_('talk.maemo.org'), main._tmo_homepage),
+#	(_('talk.maemo.org'), main._tmo_homepage),
         ]
 
     menu_bar = hildon.AppMenu()
